// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
//	test the inter-chip gaps of EPN
//
//	REFERENCES:
//		[1] : "The behavior of the chip boundaries in pn-EPIC", M. Popp
//
//	UL, Thu Sep 30 11:46:13 MET DST 1999
//
#include <cmath>
#include <iostream>
#include "CalServer.h"
#include "GeometryDataServer.h"

using namespace std;

int main(int argc, char **argv)
{
	if (argc != 3)
		errstr<<"Usage "<<argv[0]<<" cc2x cc2y"
			  <<Sas::error("TooFewArguments");

	double x = atof(argv[1]),
		   y = atof(argv[2]);

	calServer.setInstrument(Xmm::EMOS2);
	calServer.state()->randomize()->set(false);
	calServer.state()->temperature()->set(293.);
	calServer.state()->temperatureCamera()->set(293);

	//
	//	check GeometryDataServer::onCcd()
	//
	GeometryDataServer *ct = 0; ct = calServer.getAtom(ct);
	cout<<x<<'/'<<y<<" is on CCD: "<<ct->onCcd(x, y)<<endl;

	return 0;
}


