// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
//	test the Out-of-FOV access and screen thresholds
//
//	REFERENCES:
//
//	RDS, April 3 2009
//
#include <cmath>
#include <iostream>
#include "CalServer.h"
#include "GeometryDataServer.h"

using namespace std;

int main()
{
	calServer.setInstrument(Xmm::EMOS2);
	calServer.state()->randomize()->set(false);
	calServer.state()->temperature()->set(293.);
	calServer.state()->temperatureCamera()->set(293);

	//
	calServer.state()->ccd()->set(4);

        // Get the corners
	GeometryDataServer *ct = 0; ct = calServer.getAtom(ct);

        vector<string> corners = ct->corners();
        cout<<corners[0]<<endl;

        // Get the screen thresholds
	ScreenThresholdServer *st = 0; st = calServer.getAtom(st);

        cout<<"Soft band min: "<<st->softbandmin()<<endl;
        cout<<"Soft band max: "<<st->softbandmax()<<endl;
        cout<<"hard band min: "<<st->hardbandmin()<<endl;
        cout<<"Hard band max: "<<st->hardbandmax()<<endl;
        cout<<"Rate band min: "<<st->ratebandmin()<<endl;
        cout<<"Rate band max: "<<st->ratebandmax()<<endl;
        cout<<"Thresh: "<<st->threshold()<<endl;

	return 0;
}


