// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
//	test the rgs background server
//
#include <iostream>
#include <cmath>
#include "CalServer.h"
#include "Xmm.h"
#include "RgsBackgroundServer.h"

using namespace std;

static void process(XmmInstrument &rgsunit, unsigned inorder,
                      double xpsf, double pipsf)
{
	cerr<<"Instrument: "<<Xmm::toString(rgsunit.id())<<endl;
	cerr<<"Order: "<<inorder<<endl;
	calServer.setInstrument(rgsunit.id());

	RgsBackgroundServer *rbs = 0; rbs = calServer.getAtom(rbs);

 // Set the order to 1 and find the corresponding number of levels
    rbs->order(inorder);
    rbs->pipsfFrac(pipsf);
    rbs->units("BETA");
    //rbs->units("LAMBDA");

    //Now dont set this fraction as it default to 1.0  rbs->xpsfFrac(xpsf);
    unsigned nlevel = rbs->numberExtensions();
    cout<< "Num extensions: "<<nlevel<<" "<<xpsf<<endl;

	for (unsigned l = 0; l<nlevel; ++l) {
        double expos = rbs->level(l).exposure();
        double level = rbs->level(l).bckgndLevel();
  		vector<int16> channel = rbs->level(l).channel();
  		vector<int> counts = rbs->level(l).counts();
        vector<int16> quality = rbs->level(l).quality();
        vector<float> areascal = rbs->level(l).areascal();
        vector<float> backscal = rbs->level(l).backscal();

		cout<<"Level,expos,chan(1271),counts(1271),qual[40],area(1271), bckscal(1271): "
            <<level<<" "<<expos<<" "<<channel[1271]<<" "<<counts[1271]
            <<" "<<quality[40]<<" "<<areascal[1271]<<" "<<backscal[1271]<<endl;
    }
}

int main()
{
	process(xmmPayLoad.rgs1,1,0.90,0.90);
	process(xmmPayLoad.rgs2,2,0.90,0.90);

	return 0;
}

