// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
//	test the RGS HTR background classes
//
#include <iostream>
#include <cassert>
#include "CalServer.h"
#include "BackgroundDataServer.h"

using namespace std;

bool isClose(double a, double b)
{
	if (fabs(b) < 5.e-5)
		//	absolute
		return fabs(a) < 5.e-5;
	else
		return fabs(fabs(a)/fabs(b)-1.) < 5.e-5;
}


int main()
{
	//	setup the the Cal server
	const Xmm::Instrument instrument = Xmm::RGS1;
	calServer.setInstrument(instrument);
	calServer.state()->ccd()->set(1);
	calServer.state()->mode()->set(Xmm::HIGH_TIME_RESOLUTION_SINGLE_CCD);
	calServer.state()->node()->set(RGScam::PRIMARY_NODE);

	//	get the atom
	BackgroundDataServer *bkg = 0; bkg = calServer.getAtom(bkg);
	HtrBackgroundIntensity htrbh = bkg->betaSelect(.0054);
	cout<<"integrated intensity in range [500, 600]: "
		<<htrbh.accumulatedIntensity(500., 600.)<<endl;

	return 0;
}







