! ESA (C) 2000-2018
!
! This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
!
!    SAS is free software: you can redistribute it and/or modify
!    it under the terms of the GNU General Public License as published by
!    the Free Software Foundation, either version 3 of the License, or
!    (at your option) any later version.
!
!    SAS is distributed in the hope that it will be useful,
!    but WITHOUT ANY WARRANTY; without even the implied warranty of
!    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!    GNU General Public License for more details.
!
!    You should have received a copy of the GNU General Public License
!    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
!
!   psftest.f90  --- f90 program to test the PSF-related CAL routines
!
!   DESCRIPTION:
!       This tests a few aspects of the PSF-related CAL routines
!
program vigtest

use cal             ! use the Calibration Access Layer
use dal
use errorhandling

    implicit none
    logical                        :: isClose
    integer, dimension(0:2)        :: insVec = (/EMOS1, EMOS2, EPN/)
    integer, dimension(0:3)        :: accVec = (/ACCURACY_LOW, &
                                                 ACCURACY_MEDIUM, &
                                                 ACCURACY_EXTENDED, &
                                                 ACCURACY_HIGH/)
    integer                        :: ins, acc, Ei, nx, ny, iter, xTh, xPhi, i
    real ::       vigval
!    real(double), dimension(0:2)   :: Evec = (/1500, 4500, 8500/)
    real(double), dimension(0:7)   :: Evec = (/200, 500, 1000, 1500, 2000, 4500, 8500, 10000/)
    real(double), dimension(0:15)   :: Theta = (/ (i*60, i=0,15) /)
    real(double), dimension(0:12)   :: Phi = (/ (i*30, i=0,12) /)
    real(double)                   :: E, ee, onAxisVal
    real(double)                   :: T,P
    type(PsfT)                     :: psf
    type(PsfValidityRangesT)       :: valRange
    type(PsfBinSizeT)              :: binSize
    type(PsfWindowT)               :: window
    logical                        :: binSizeChangeable
    real(single), dimension(:,:), pointer :: map

    iter = 0
    !acc=0
    ! setting ACCURACY_HIGH
    acc=3
    do ins=0, size(insVec)-1
            call CAL_setState(instrument=insVec(ins), &
                              accuracyLevel=accVec(acc))
            do Ei=0, size(Evec-1)-1
              do xTh=0, size(Theta-1)-1
                do xPhi=0, size(Phi-1)-1
      			       E = Evec(Ei)
                   T = Theta(xTh)
                   P = Phi(xPhi)
                        P = P /(180.0/3.14159)
      			       write(*, *) 'Retrieving vig fact for ', instId(insVec(ins)), &
      				           ' acc=', acc, 'at E=', E, ' eV'
      			       vigval = CAL_getVignettingFactor(E,T,P)
      			       write(*, *) insVec(ins), E, T, P, vigval
                enddo
              enddo
            enddo
    enddo

    call message(AppMsg, Verbose, "all tests passed")
end program


logical function isClose(value, trueval)
use types

    real(double), intent(in)    :: value, trueval
    real(double)                :: absval, abstrueval

    isClose = .true.
    if (value * trueval .lt. 0.) isClose = .false.
    absval = abs(value)
     abstrueval = abs(trueval)
    if (absval .lt. .9999 * abstrueval .or. &
        absval .gt. 1.001 * abstrueval) isClose = .false.
end function isClose
